float g_fBlendFactor;
float2 g_vTextureSize0;
float2 g_vTextureSize1;
float2 g_vDestinationSize;

texture2D Texture0;
texture2D Texture1;

sampler2D PointSampler0 = sampler_state
{
    Texture = <Texture0>;
    MinFilter = POINT;
    MagFilter = POINT;
    MipFilter = POINT;
};

sampler2D PointSampler1 = sampler_state
{
    Texture = <Texture1>;
    MinFilter = POINT;
    MagFilter = POINT;
    MipFilter = POINT;
};

sampler2D LinearSampler0 = sampler_state
{
    Texture = <Texture0>;
    MinFilter = LINEAR;
    MagFilter = LINEAR;
    MipFilter = LINEAR;
};

sampler2D LinearSampler1 = sampler_state
{
    Texture = <Texture1>;
    MinFilter = LINEAR;
    MagFilter = LINEAR;
    MipFilter = LINEAR;
};

static const int BlurRadius = 4;
static const float BlurWeights[BlurRadius * 2 + 1] = 
{
	0.026995,
    0.064759,
    0.120985,
    0.176033,
    0.199471,
    0.176033,
    0.120985,
    0.064759,
    0.026995,
};

float CalcGaussianWeight(int iSamplePoint)
{
	return BlurWeights[iSamplePoint + BlurRadius] * 1.075f;
}

void PostProcessVS (	in float3 in_vPositionOS		: POSITION,
						in float3 in_vTexCoord			: TEXCOORD0,					
						out float4 out_vPositionCS		: POSITION,
						out float2 out_vTexCoord		: TEXCOORD0	)
{
	out_vPositionCS.x = in_vPositionOS.x - (1.0f / g_vDestinationSize.x);
	out_vPositionCS.y = in_vPositionOS.y + (1.0f / g_vDestinationSize.y);
	out_vPositionCS.z = in_vPositionOS.z;
	out_vPositionCS.w = 1.0f;
	out_vTexCoord = in_vTexCoord.xy;
}	

float4 BlendPS(float2 in_vTexCoord : TEXCOORD0) : COLOR0
{
	float4 vColor0 = tex2D(PointSampler0, in_vTexCoord);
	float4 vColor1 = tex2D(PointSampler1, in_vTexCoord);
	return lerp(vColor0, vColor1, g_fBlendFactor);	
}

float4 BlurHPS(float2 in_vTexCoord : TEXCOORD0) : COLOR0
{
	float4 vBlurred = 0;
	for (int x = -BlurRadius; x <= BlurRadius; x++)
		vBlurred += tex2D(PointSampler0, in_vTexCoord + (float2(x, 0) / g_vTextureSize0)) * CalcGaussianWeight(x);
	return vBlurred;
}

float4 BlurVPS(float2 in_vTexCoord : TEXCOORD0) : COLOR0
{
	float4 vBlurred = 0;
	for (int y = -BlurRadius; y <= BlurRadius; y++)
		vBlurred += tex2D(PointSampler0, in_vTexCoord + (float2(0, y) / g_vTextureSize0)) * CalcGaussianWeight(y);
	return vBlurred;
}

float4 SimplePS(float2 in_vTexCoord : TEXCOORD0) : COLOR0
{
	return tex2D(LinearSampler0, in_vTexCoord);
}

technique Simple
{
	pass p0
	{
		VertexShader = compile vs_1_1 PostProcessVS();
		PixelShader = compile ps_2_0 SimplePS();		
	}
}

technique Blend
{
	pass p0
	{
		VertexShader = compile vs_1_1 PostProcessVS();
		PixelShader = compile ps_2_0 BlendPS();		
	}
}

technique BlurH
{
	pass p0
	{
		VertexShader = compile vs_1_1 PostProcessVS();
		PixelShader = compile ps_2_0 BlurHPS();		
	}
}

technique BlurV
{
	pass p0
	{
		VertexShader = compile vs_1_1 PostProcessVS();
		PixelShader = compile ps_2_0 BlurVPS();		
	}
}

