﻿//======================================================================
//
//	Cross-Platform XNA Menu System
//  http://cpxms.codeplex.com/
//
//  All code and content licensed under Microsoft Public License (Ms-PL)	
//
//======================================================================
//
//	File:		Panel.cs
//
//	Author:		MJP
//
//	Date:		04/27/09
//
//======================================================================

using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Reflection;
using System.ComponentModel;
using System.Collections.ObjectModel;
using System.Xml.Serialization;
using System.Drawing.Design;

using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;


namespace CPXMenu
{
	/// <summary>
	/// A generic host for other items
	/// </summary>
    [CanHaveChildren(true)]
    [IconKey("Panel")]
    [Selectable(true)]
    [Movable(true)]
    [Sizeable(true)]
    [CanCopyPaste(true)]
    [Description("A generic host for other items")]
    public class Panel : MenuItem
    {
		public const string DefaultImage = "CPXMenu Content\\Textures\\PanelBackground";

        private ImageState imageState = new ImageState();

		/// <summary>
		/// Gets or sets the ImageState that controls the image and background color of the panel
		/// </summary>
        [Browsable(true)]
        [Category("Appearance")]
        [Description("Controls the appearance of the Panel")]
        public ImageState ImageState
        {
            get { return imageState; }
            set
            {
                imageState = value;
                ImageStates.Clear();
                ImageStates.Add(imageState);
            }
        }

		/// <summary>
		/// Creates a new Panel
		/// </summary>
        public Panel()
            : base()
        {
            Dimensions = new Point(400, 300);

			imageState.BackgroundColor = Color.TransparentBlack;
			imageState.TextureName = DefaultImage;
            ImageState = imageState;
            ImageStateIndex = 0;
        }

        /// <summary>
        /// Creates a clone of the item
        /// </summary>
        /// <returns>A clone of the item</returns>
        public override MenuItem Clone()
        {
            Panel clone = (Panel)base.Clone();

            clone.imageState = this.imageState.Clone();
            clone.ImageStates.Add(clone.imageState);

            return clone;
        }
    }
}